@@ -7,8 +7,8 @@ import (
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -20,12 +20,14 @@ func main() {
 
 	for i := 0; i < numBars; i++ {
 		name := fmt.Sprintf("Bar#%d:", i)
-		efn := func(w io.Writer, _ int, s decor.Statistics) {
+		efn := func(w io.Writer, s decor.Statistics) (err error) {
 			if s.Completed {
-				fmt.Fprintf(w, "Bar id: %d has been completed\n", s.ID)
+				_, err = fmt.Fprintf(w, "Bar id: %d has been completed\n", s.ID)
 			}
+			return err
 		}
-		bar := p.AddBar(int64(total), mpb.BarExtender(mpb.BarFillerFunc(efn)),
+		bar := p.AddBar(int64(total),
+			mpb.BarExtender(mpb.BarFillerFunc(efn), false),
 			mpb.PrependDecorators(
 				// simple name decorator
 				decor.Name(name),
@@ -35,8 +37,8 @@ func main() {
 			mpb.AppendDecorators(
 				// replace ETA decorator with "done" message, OnComplete event
 				decor.OnComplete(
-					// ETA decorator with ewma age of 60
-					decor.EwmaETA(decor.ET_STYLE_GO, 60), "done",
+					// ETA decorator with ewma age of 30
+					decor.EwmaETA(decor.ET_STYLE_GO, 30), "done",
 				),
 			),
 		)
@@ -50,9 +52,8 @@ func main() {
 				// EWMA's unit of measure is an iteration's duration
 				start := time.Now()
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-				bar.Increment()
-				// since EWMA based decorator is used, DecoratorEwmaUpdate should be called
-				bar.DecoratorEwmaUpdate(time.Since(start))
+				// we need to call EwmaIncrement to fulfill ewma decorator's contract
+				bar.EwmaIncrement(time.Since(start))
 			}
 		}()
 	}
