@@ -6,8 +6,8 @@ import (
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -34,8 +34,8 @@ func main() {
 			mpb.AppendDecorators(
 				// replace ETA decorator with "done" message, OnComplete event
 				decor.OnComplete(
-					// ETA decorator with ewma age of 60
-					decor.EwmaETA(decor.ET_STYLE_GO, 60), "done",
+					// ETA decorator with ewma age of 30
+					decor.EwmaETA(decor.ET_STYLE_GO, 30), "done",
 				),
 			),
 		)
@@ -49,9 +49,8 @@ func main() {
 				// EWMA's unit of measure is an iteration's duration
 				start := time.Now()
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-				bar.Increment()
-				// we need to call DecoratorEwmaUpdate to fulfill ewma decorator's contract
-				bar.DecoratorEwmaUpdate(time.Since(start))
+				// we need to call EwmaIncrement to fulfill ewma decorator's contract
+				bar.EwmaIncrement(time.Since(start))
 			}
 		}()
 	}
