@@ -6,8 +6,8 @@ import (
 	"io/ioutil"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -22,12 +22,12 @@ func main() {
 	bar := p.New(total,
 		mpb.BarStyle().Rbound("|"),
 		mpb.PrependDecorators(
-			decor.CountersKibiByte("% .2f / % .2f"),
+			decor.Counters(decor.SizeB1024(0), "% .2f / % .2f"),
 		),
 		mpb.AppendDecorators(
-			decor.EwmaETA(decor.ET_STYLE_GO, 90),
+			decor.EwmaETA(decor.ET_STYLE_GO, 30),
 			decor.Name(" ] "),
-			decor.EwmaSpeed(decor.UnitKiB, "% .2f", 60),
+			decor.EwmaSpeed(decor.SizeB1024(0), "% .2f", 30),
 		),
 	)
 
@@ -36,7 +36,7 @@ func main() {
 	defer proxyReader.Close()
 
 	// copy from proxyReader, ignoring errors
-	io.Copy(ioutil.Discard, proxyReader)
+	_, _ = io.Copy(ioutil.Discard, proxyReader)
 
 	p.Wait()
 }
