@@ -5,13 +5,13 @@ import (
 	"math/rand"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
+	rng := rand.New(rand.NewSource(time.Now().UnixNano()))
 	p := mpb.New(mpb.PopCompletedMode())
-
 	total, numBars := 100, 4
 	for i := 0; i < numBars; i++ {
 		name := fmt.Sprintf("Bar#%d:", i)
@@ -28,16 +28,14 @@ func main() {
 			),
 		)
 		// simulating some work
-		rng := rand.New(rand.NewSource(time.Now().UnixNano()))
 		max := 100 * time.Millisecond
 		for i := 0; i < total; i++ {
 			// start variable is solely for EWMA calculation
 			// EWMA's unit of measure is an iteration's duration
 			start := time.Now()
 			time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-			bar.Increment()
-			// we need to call DecoratorEwmaUpdate to fulfill ewma decorator's contract
-			bar.DecoratorEwmaUpdate(time.Since(start))
+			// we need to call EwmaIncrement to fulfill ewma decorator's contract
+			bar.EwmaIncrement(time.Since(start))
 		}
 	}
 
