@@ -6,8 +6,8 @@ import (
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func main() {
@@ -20,9 +20,20 @@ func main() {
 	total, numBars := 101, 3
 	wg.Add(numBars)
 
+	condFillerBuilder := func(cond bool) mpb.BarFillerBuilder {
+		if cond {
+			s := mpb.SpinnerStyle("∙∙∙", "●∙∙", "∙●∙", "∙∙●", "∙∙∙")
+			return s.Meta(func(s string) string {
+				return "\033[31m" + s + "\033[0m" // red
+			})
+		}
+		return mpb.BarStyle().Lbound("╢").Filler("▌").Tip("▌").Padding("░").Rbound("╟")
+	}
+
 	for i := 0; i < numBars; i++ {
 		name := fmt.Sprintf("Bar#%d:", i)
-		bar := p.New(int64(total), condBuilder(i != 0),
+		bar := p.New(int64(total),
+			condFillerBuilder(i != 0),
 			mpb.PrependDecorators(
 				// simple name decorator
 				decor.Name(name),
@@ -30,8 +41,8 @@ func main() {
 			mpb.AppendDecorators(
 				// replace ETA decorator with "done" message, OnComplete event
 				decor.OnComplete(
-					// ETA decorator with ewma age of 60
-					decor.EwmaETA(decor.ET_STYLE_GO, 60), "done",
+					// ETA decorator with ewma age of 30
+					decor.EwmaETA(decor.ET_STYLE_GO, 30), "done",
 				),
 			),
 		)
@@ -45,23 +56,11 @@ func main() {
 				// EWMA's unit of measure is an iteration's duration
 				start := time.Now()
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
-				bar.Increment()
-				// we need to call DecoratorEwmaUpdate to fulfill ewma decorator's contract
-				bar.DecoratorEwmaUpdate(time.Since(start))
+				// we need to call EwmaIncrement to fulfill ewma decorator's contract
+				bar.EwmaIncrement(time.Since(start))
 			}
 		}()
 	}
 	// wait for passed wg and for all bars to complete and flush
 	p.Wait()
 }
-
-func condBuilder(cond bool) mpb.BarFillerBuilder {
-	return mpb.BarFillerBuilderFunc(func() mpb.BarFiller {
-		if cond {
-			// spinner Bar on cond
-			frames := []string{"∙∙∙", "●∙∙", "∙●∙", "∙∙●", "∙∙∙"}
-			return mpb.SpinnerStyle(frames...).Build()
-		}
-		return mpb.BarStyle().Lbound("╢").Filler("▌").Tip("▌").Padding("░").Rbound("╟").Build()
-	})
-}
