@@ -1,23 +1,35 @@
 package main
 
 import (
+	"flag"
 	"fmt"
 	"math/rand"
+	"os"
 	"sync"
 	"time"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/pkg/profile"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 const (
 	totalBars = 32
 )
 
+var proftype = flag.String("prof", "", "profile type (cpu, mem)")
+
 func main() {
+	flag.Parse()
+	switch *proftype {
+	case "cpu":
+		defer profile.Start(profile.CPUProfile, profile.ProfilePath("."), profile.NoShutdownHook).Stop()
+	case "mem":
+		defer profile.Start(profile.MemProfile, profile.ProfilePath("."), profile.NoShutdownHook).Stop()
+	}
 	var wg sync.WaitGroup
 	// passed wg will be accounted at p.Wait() call
-	p := mpb.New(mpb.WithWaitGroup(&wg))
+	p := mpb.New(mpb.WithWaitGroup(&wg), mpb.WithDebugOutput(os.Stderr))
 	wg.Add(totalBars)
 
 	for i := 0; i < totalBars; i++ {
@@ -25,8 +37,8 @@ func main() {
 		total := rand.Intn(320) + 10
 		bar := p.AddBar(int64(total),
 			mpb.PrependDecorators(
-				decor.Name(name),
-				decor.Elapsed(decor.ET_STYLE_GO, decor.WCSyncSpace),
+				decor.Name(name, decor.WCSyncWidthR),
+				decor.Elapsed(decor.ET_STYLE_GO, decor.WCSyncWidth),
 			),
 			mpb.AppendDecorators(
 				decor.OnComplete(
