@@ -1,11 +1,10 @@
 package mpb_test
 
 import (
-	"sync"
 	"testing"
 
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 func TestNameDecorator(t *testing.T) {
@@ -32,7 +31,7 @@ func TestNameDecorator(t *testing.T) {
 	}
 
 	for _, test := range tests {
-		got := test.decorator.Decor(decor.Statistics{})
+		got, _ := test.decorator.Decor(decor.Statistics{})
 		if got != test.want {
 			t.Errorf("Want: %q, Got: %q\n", test.want, got)
 		}
@@ -183,30 +182,25 @@ func testDecoratorConcurrently(t *testing.T, testCases [][]step) {
 	}
 
 	for _, columnCase := range testCases {
-		mpb.SyncWidth(toSyncMatrix(columnCase))
-		numBars := len(columnCase)
-		gott := make([]chan string, numBars)
-		wg := new(sync.WaitGroup)
-		wg.Add(numBars)
-		for i, step := range columnCase {
+		mpb.SyncWidth(toSyncMatrix(columnCase), nil)
+		var results []chan string
+		for _, step := range columnCase {
 			step := step
-			ch := make(chan string, 1)
+			ch := make(chan string)
 			go func() {
-				defer wg.Done()
-				ch <- step.decorator.Decor(step.stat)
+				str, _ := step.decorator.Decor(step.stat)
+				ch <- str
 			}()
-			gott[i] = ch
+			results = append(results, ch)
 		}
-		wg.Wait()
 
-		for i, ch := range gott {
-			got := <-ch
+		for i, ch := range results {
+			res := <-ch
 			want := columnCase[i].want
-			if got != want {
-				t.Errorf("Want: %q, Got: %q\n", want, got)
+			if res != want {
+				t.Errorf("Want: %q, Got: %q\n", want, res)
 			}
 		}
-
 	}
 }
 
