@@ -773,8 +773,13 @@ func TestDrawDefault(t *testing.T) {
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
+			s.completed = tc.total > 0 && tc.current >= tc.total
 			tmpBuf.Reset()
-			_, err := tmpBuf.ReadFrom(s.draw(newStatistics(tw, s)))
+			r, err := s.draw(newStatistics(tw, s))
+			if err != nil {
+				t.FailNow()
+			}
+			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
 			}
@@ -805,14 +810,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 	}{
 		3: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    "  ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -822,14 +827,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		4: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -837,14 +842,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[=>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -854,14 +859,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		5: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -869,14 +874,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[==>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -886,14 +891,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		6: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [=>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -901,14 +906,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[===>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [=>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -918,14 +923,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		7: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [==>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -933,14 +938,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[====>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [==>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -950,14 +955,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		8: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [===>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -965,14 +970,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[=====>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [===>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -982,14 +987,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		80: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}",
 				total:   60,
 				current: 59,
 				want:    " [==========================================================================>-] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,59}trim",
 				total:   60,
 				current: 59,
@@ -997,7 +1002,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[============================================================================>-]",
 			},
 			{
-				style:    BarStyle().TipOnComplete(">"),
+				style:    BarStyle().TipOnComplete(),
 				name:     "t,c,bw{60,59,60}",
 				total:    60,
 				current:  59,
@@ -1005,7 +1010,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:     " [========================================================>-] ",
 			},
 			{
-				style:    BarStyle().TipOnComplete(">"),
+				style:    BarStyle().TipOnComplete(),
 				name:     "t,c,bw{60,59,60}trim",
 				total:    60,
 				current:  59,
@@ -1014,14 +1019,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:     "[========================================================>-]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}",
 				total:   60,
 				current: 60,
 				want:    " [===========================================================================>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{60,60}trim",
 				total:   60,
 				current: 60,
@@ -1029,7 +1034,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[=============================================================================>]",
 			},
 			{
-				style:    BarStyle().TipOnComplete(">"),
+				style:    BarStyle().TipOnComplete(),
 				name:     "t,c,bw{60,60,60}",
 				total:    60,
 				current:  60,
@@ -1037,7 +1042,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:     " [=========================================================>] ",
 			},
 			{
-				style:    BarStyle().TipOnComplete(">"),
+				style:    BarStyle().TipOnComplete(),
 				name:     "t,c,bw{60,60,60}trim",
 				total:    60,
 				current:  60,
@@ -1048,14 +1053,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		99: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,99}",
 				total:   100,
 				current: 99,
 				want:    " [=============================================================================================>-] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,99}trim",
 				total:   100,
 				current: 99,
@@ -1063,14 +1068,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[===============================================================================================>-]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,100}",
 				total:   100,
 				current: 100,
 				want:    " [==============================================================================================>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,100}trim",
 				total:   100,
 				current: 100,
@@ -1078,7 +1083,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[================================================================================================>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,99}",
 				total:   100,
 				current: 100,
@@ -1086,7 +1091,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    " [++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,99}trim",
 				total:   100,
 				current: 100,
@@ -1095,16 +1100,16 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete("<").Reverse(),
-				name:    `t,c,r{100,100,99}TipOnComplete("<").Reverse()`,
+				style:   BarStyle().Tip("<").TipOnComplete().Reverse(),
+				name:    `t,c,r{100,100,99}.Tip("<").TipOnComplete().Reverse()`,
 				total:   100,
 				current: 100,
 				refill:  99,
 				want:    " [<++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete("<").Reverse(),
-				name:    `t,c,r{100,100,99}TipOnComplete("<").Reverse()trim`,
+				style:   BarStyle().Tip("<").TipOnComplete().Reverse(),
+				name:    `t,c,r{100,100,99}.Tip("<").TipOnComplete().Reverse()trim`,
 				total:   100,
 				current: 100,
 				refill:  99,
@@ -1112,7 +1117,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[<++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,100}",
 				total:   100,
 				current: 100,
@@ -1120,7 +1125,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    " [++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,100}trim",
 				total:   100,
 				current: 100,
@@ -1129,16 +1134,16 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete("<").Reverse(),
-				name:    `t,c,r{100,100,100}TipOnComplete("<").Reverse()`,
+				style:   BarStyle().Tip("<").TipOnComplete().Reverse(),
+				name:    `t,c,r{100,100,100}.Tip("<").TipOnComplete().Reverse()`,
 				total:   100,
 				current: 100,
 				refill:  100,
 				want:    " [<++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete("<").Reverse(),
-				name:    `t,c,r{100,100,100}TipOnComplete("<").Reverse()trim`,
+				style:   BarStyle().Tip("<").TipOnComplete().Reverse(),
+				name:    `t,c,r{100,100,100}.Tip("<").TipOnComplete().Reverse()trim`,
 				total:   100,
 				current: 100,
 				refill:  100,
@@ -1148,14 +1153,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 		},
 		100: {
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,99}",
 				total:   100,
 				current: 99,
 				want:    " [==============================================================================================>-] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,99}trim",
 				total:   100,
 				current: 99,
@@ -1163,14 +1168,14 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[================================================================================================>-]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,100}",
 				total:   100,
 				current: 100,
 				want:    " [===============================================================================================>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c{100,100}trim",
 				total:   100,
 				current: 100,
@@ -1178,7 +1183,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[=================================================================================================>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,99}",
 				total:   100,
 				current: 100,
@@ -1186,7 +1191,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    " [+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,99}trim",
 				total:   100,
 				current: 100,
@@ -1195,7 +1200,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    "[+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>]",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,100}",
 				total:   100,
 				current: 100,
@@ -1203,7 +1208,7 @@ func TestDrawTipOnComplete(t *testing.T) {
 				want:    " [+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++>] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete(">"),
+				style:   BarStyle().TipOnComplete(),
 				name:    "t,c,r{100,100,100}trim",
 				total:   100,
 				current: 100,
@@ -1223,8 +1228,13 @@ func TestDrawTipOnComplete(t *testing.T) {
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
+			s.completed = tc.total > 0 && tc.current >= tc.total
 			tmpBuf.Reset()
-			_, err := tmpBuf.ReadFrom(s.draw(newStatistics(tw, s)))
+			r, err := s.draw(newStatistics(tw, s))
+			if err != nil {
+				t.FailNow()
+			}
+			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
 			}
@@ -1304,8 +1314,8 @@ func TestDrawDoubleWidth(t *testing.T) {
 				want:    " [===============================================================================================] ",
 			},
 			{
-				style:   BarStyle().TipOnComplete("だ"),
-				name:    `t,c{100,100}TipOnComplete("だ")`,
+				style:   BarStyle().Tip("だ").TipOnComplete(),
+				name:    `t,c{100,100}.Tip("だ").TipOnComplete()`,
 				total:   100,
 				current: 100,
 				want:    " [=============================================================================================だ] ",
@@ -1336,35 +1346,35 @@ func TestDrawDoubleWidth(t *testing.T) {
 				name:    `t,c{100,100}.Filler("の").Tip("だ").Padding("つ")`,
 				total:   100,
 				current: 100,
-				want:    " […ののののののののののののののののののののののののののののののののののののののののののののののの] ",
+				want:    " [ののののののののののののののののののののののののののののののののののののののののののののののの…] ",
 			},
 			{
 				style:   BarStyle().Filler("の").Tip("だ").Padding("つ").Reverse(),
 				name:    `t,c{100,100}Filler("の").Tip("だ").Padding("つ").Reverse()`,
 				total:   100,
 				current: 100,
-				want:    " [ののののののののののののののののののののののののののののののののののののののののののののののの…] ",
+				want:    " […ののののののののののののののののののののののののののののののののののののののののののののののの] ",
 			},
 			{
-				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ"),
-				name:    `t,c{100,99}Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ")`,
+				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete().Padding("つ"),
+				name:    `t,c{100,99}Filler("の").Tip("だ").TipOnComplete().Padding("つ")`,
 				total:   100,
 				current: 99,
 				want:    " [ののののののののののののののののののののののののののののののののののののののののののののののだ…] ",
 			},
 			{
-				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ"),
-				name:    `t,c{100,100}.Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ")`,
+				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete().Padding("つ"),
+				name:    `t,c{100,100}.Filler("の").Tip("だ").TipOnComplete().Padding("つ")`,
 				total:   100,
 				current: 100,
-				want:    " […ののののののののののののののののののののののののののののののののののののののののののののののだ] ",
+				want:    " [ののののののののののののののののののののののののののののののののののののののののののののののだ…] ",
 			},
 			{
-				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ").Reverse(),
-				name:    `t,c{100,100}.Filler("の").Tip("だ").TipOnComplete("だ").Padding("つ").Reverse()`,
+				style:   BarStyle().Filler("の").Tip("だ").TipOnComplete().Padding("つ").Reverse(),
+				name:    `t,c{100,100}.Filler("の").Tip("だ").TipOnComplete().Padding("つ").Reverse()`,
 				total:   100,
 				current: 100,
-				want:    " [だのののののののののののののののののののののののののののののののののののののののののののののの…] ",
+				want:    " […だのののののののののののののののののののののののののののののののののののののののののののののの] ",
 			},
 			{
 				style:   BarStyle().Refiller("の"),
@@ -1395,8 +1405,13 @@ func TestDrawDoubleWidth(t *testing.T) {
 			s.current = tc.current
 			s.trimSpace = tc.trim
 			s.refill = tc.refill
+			s.completed = tc.total > 0 && tc.current >= tc.total
 			tmpBuf.Reset()
-			_, err := tmpBuf.ReadFrom(s.draw(newStatistics(tw, s)))
+			r, err := s.draw(newStatistics(tw, s))
+			if err != nil {
+				t.FailNow()
+			}
+			_, err = tmpBuf.ReadFrom(r)
 			if err != nil {
 				t.FailNow()
 			}
