@@ -3,11 +3,10 @@ package mpb_test
 import (
 	"bytes"
 	"io"
-	"io/ioutil"
 	"strings"
 	"testing"
 
-	"github.com/vbauerster/mpb/v7"
+	"github.com/vbauerster/mpb/v8"
 )
 
 const content = `Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do
@@ -29,21 +28,21 @@ func (r *testReader) Read(p []byte) (n int, err error) {
 }
 
 func TestProxyReader(t *testing.T) {
-	p := mpb.New(mpb.WithOutput(ioutil.Discard))
+	p := mpb.New(mpb.WithOutput(io.Discard))
 
-	tReader := &testReader{strings.NewReader(content), false}
+	tr := &testReader{strings.NewReader(content), false}
 
-	bar := p.AddBar(int64(len(content)), mpb.BarFillerTrim())
+	bar := p.New(int64(len(content)), mpb.NopStyle())
 
 	var buf bytes.Buffer
-	_, err := io.Copy(&buf, bar.ProxyReader(tReader))
+	_, err := io.Copy(&buf, bar.ProxyReader(tr))
 	if err != nil {
-		t.Errorf("Error copying from reader: %+v\n", err)
+		t.Errorf("io.Copy: %s\n", err.Error())
 	}
 
 	p.Wait()
 
-	if !tReader.called {
+	if !tr.called {
 		t.Error("Read not called")
 	}
 
@@ -52,34 +51,63 @@ func TestProxyReader(t *testing.T) {
 	}
 }
 
-type testWriterTo struct {
+type testReadCloser struct {
 	io.Reader
-	wt     io.WriterTo
 	called bool
 }
 
-func (wt *testWriterTo) WriteTo(w io.Writer) (n int64, err error) {
-	wt.called = true
-	return wt.wt.WriteTo(w)
+func (r *testReadCloser) Close() error {
+	r.called = true
+	return nil
 }
 
-func TestProxyWriterTo(t *testing.T) {
-	p := mpb.New(mpb.WithOutput(ioutil.Discard))
+func TestProxyReadCloser(t *testing.T) {
+	p := mpb.New(mpb.WithOutput(io.Discard))
 
-	var reader io.Reader = strings.NewReader(content)
-	tReader := &testWriterTo{reader, reader.(io.WriterTo), false}
+	tr := &testReadCloser{strings.NewReader(content), false}
 
-	bar := p.AddBar(int64(len(content)), mpb.BarFillerTrim())
+	bar := p.New(int64(len(content)), mpb.NopStyle())
+
+	rc := bar.ProxyReader(tr)
+	_, err := io.Copy(io.Discard, rc)
+	if err != nil {
+		t.Errorf("io.Copy: %s\n", err.Error())
+	}
+	_ = rc.Close()
+
+	p.Wait()
+
+	if !tr.called {
+		t.Error("Close not called")
+	}
+}
+
+type testReaderWriterTo struct {
+	io.Reader
+	called bool
+}
+
+func (r *testReaderWriterTo) WriteTo(w io.Writer) (n int64, err error) {
+	r.called = true
+	return r.Reader.(io.WriterTo).WriteTo(w)
+}
+
+func TestProxyReaderWriterTo(t *testing.T) {
+	p := mpb.New(mpb.WithOutput(io.Discard))
+
+	tr := &testReaderWriterTo{strings.NewReader(content), false}
+
+	bar := p.New(int64(len(content)), mpb.NopStyle())
 
 	var buf bytes.Buffer
-	_, err := io.Copy(&buf, bar.ProxyReader(tReader))
+	_, err := io.Copy(&buf, bar.ProxyReader(tr))
 	if err != nil {
-		t.Errorf("Error copying from reader: %+v\n", err)
+		t.Errorf("io.Copy: %s\n", err.Error())
 	}
 
 	p.Wait()
 
-	if !tReader.called {
+	if !tr.called {
 		t.Error("WriteTo not called")
 	}
 
